//+------------------------------------------------------------------+
//|                                                   BAT ATR v2.mq4 |
//+------------------------------------------------------------------+
#property  copyright "Copyright Team Aphid"
#property  link      ""

//---- indicator settings
#property  indicator_chart_window
#property  indicator_buffers 2
#property  indicator_color1  DarkOrange
#property  indicator_width1  2
#property  indicator_style1  1
#property  indicator_color2  Green
#property  indicator_width2  2
#property  indicator_style2  1

//---- indicator parameters
extern  int      BackPeriod     = 2000;
extern  int      ATRPeriod      = 5;
extern  double   Factor         = 3.5;
extern  bool     MedianPrice    = true;
extern  bool     MedianBase     = true;
extern  bool     CloseBase      = true;
extern  double   distance       = 0;
extern  bool     ChartAlerts    = true;
extern  bool     EmailAlerts    = false;

//---- indicator buffers
double     ind_buffer1[];
double     ind_buffer2[];

int        LastAlertDir = 0;

//+------------------------------------------------------------------+
int init()  {
//+------------------------------------------------------------------+
  SetIndexStyle(0,DRAW_LINE,EMPTY,2);
  SetIndexDrawBegin(0,ATRPeriod);
  SetIndexBuffer(0,ind_buffer1);
  SetIndexStyle(1,DRAW_LINE,EMPTY,2);
  SetIndexDrawBegin(1,ATRPeriod);
  SetIndexBuffer(1,ind_buffer2);

  IndicatorDigits(MarketInfo(Symbol(),MODE_DIGITS)+2);

  IndicatorShortName("BAT ATR("+ATRPeriod+" * "+Factor+")");
  SetIndexLabel(0,"Support");
  SetIndexLabel(1,"Resistance");

  return(0);
}

//+------------------------------------------------------------------+
int deinit()  {
//+------------------------------------------------------------------+
  return(0);
}

//+------------------------------------------------------------------+
int start()  {
//+------------------------------------------------------------------+
  int limit;
  int counted_bars=IndicatorCounted();
  double PrevUp, PrevDn;
  double CurrUp, CurrDn;
  double PriceCurr, PricePrev;
  double PriceLvl;
  double PriceHLorC;
  double LvlUp = 0;
  double LvlDn = 1000;
  int Dir = 1;
  int InitDir;
  double val;
  
  if(counted_bars<0) return(-1);
  if(counted_bars>0) counted_bars--;
  if (BackPeriod==0) limit=Bars-counted_bars; else limit=BackPeriod;

  InitDir = 0;
  for (int i=limit; i>=0; i--)   {
    if (MedianPrice) 
      PriceLvl = (High[i] + Low[i])/2;
    else 
      PriceLvl = Close[i];  
     
    if (MedianBase)  {
      PriceCurr = (High[i] + Low[i])/2;
      PricePrev = (High[i-1] + Low[i-1])/2;
    } else {
      PriceCurr = Close[i];
      PricePrev = Close[i-1];
    }
     
    if (InitDir == 0)  {
      CurrUp=PriceCurr - (iATR(NULL,0,ATRPeriod,i) * Factor);
      PrevUp=PricePrev - (iATR(NULL,0,ATRPeriod,i-1) * Factor);
      CurrDn=PriceCurr + (iATR(NULL,0,ATRPeriod,i) * Factor);
      PrevDn=PricePrev + (iATR(NULL,0,ATRPeriod,i-1) * Factor);
          
      if (CurrUp > PrevUp) Dir = 1;
      LvlUp = CurrUp;
      if (CurrDn < PrevDn) Dir = -1;
      LvlDn = CurrDn;
      InitDir = 1;
    }
     
    CurrUp=PriceLvl - (iATR(NULL,0,ATRPeriod,i) * Factor);
    CurrDn=PriceLvl + (iATR(NULL,0,ATRPeriod,i) * Factor);

    if (Dir == 1)  {
      if (CurrUp > LvlUp) {
        ind_buffer1[i] = CurrUp-distance;
        LvlUp = CurrUp;
      } else {
        ind_buffer1[i] = LvlUp-distance;
      }

      ind_buffer2[i] = EMPTY_VALUE;
      if (CloseBase) 
        PriceHLorC = Close[i]; 
      else 
        PriceHLorC = Low[i];
      if (PriceHLorC < ind_buffer1[i]) {
        Dir = -1;
        LvlDn = 1000;
    } }
     
    if (Dir == -1)  {
      if (CurrDn < LvlDn) {
        ind_buffer2[i] = CurrDn+distance;
        LvlDn = CurrDn;
      } else {
        ind_buffer2[i] = LvlDn+distance;
      }

      ind_buffer1[i] = EMPTY_VALUE;
      if (CloseBase) 
        PriceHLorC = Close[i]; 
      else 
        PriceHLorC = High[i];
      if (PriceHLorC > ind_buffer2[i]) {
        Dir = 1;
        LvlUp = 0;
    } }

    if (i==1 && LastAlertDir != Dir)  {
      string alert = "";
      if (LastAlertDir == 1)   alert = "SELL";
      if (LastAlertDir == -1)  alert = "BUY";
      alert = Symbol() + "," + TFToStr(Period()) + ": BAT " + alert + " signal";
      if (ChartAlerts && LastAlertDir != 0)    Alert(alert);
      if (EmailAlerts && LastAlertDir != 0)    SendMail(alert,"");
      LastAlertDir = Dir;
    }  
  }  
  return(0);
}

//+------------------------------------------------------------------+
string TFToStr(int tf)
//+------------------------------------------------------------------+
// Converts a MT4-numeric timeframe to its descriptor string
// Usage:   string s=TFToStr(15) returns s="M15"
{
  switch (tf)  {
    case     1 :  return("M1");
    case     5 :  return("M5");
    case    15 :  return("M15");
    case    30 :  return("M30");
    case    60 :  return("H1");
    case   240 :  return("H4");
    case  1440 :  return("D1");
    case 10080 :  return("W1");
    case 43200 :  return("MN");
  }  
  return(0);
}  

